<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package zeino
 */
?>
<!doctype html>
<html <?php esc_attr(language_attributes()); ?>>
<head>
	<meta charset="<?php esc_attr(bloginfo( 'charset' )); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
    <?php wp_body_open(); ?>

    <?php if ( 'on' == get_theme_mod( 'preloader', 'on' ) ) : ?>
        <div class="preloader"></div><!-- /.preloader -->
    <?php endif; ?>
	<div class="page-wrapper">

		<header class="site-header header-one">

            <?php $zeino_header_stricky_class = ( true == get_theme_mod( 'header_stricked_menu', true ) ) ? 'stricky' : '' ; ?>
            <nav class="navbar navbar-expand-lg navbar-light header-navigation <?php if( ! is_user_logged_in() ) { echo esc_attr( $zeino_header_stricky_class ); }; ?>">
                <div class="container clearfix">
                    <!-- Brand and toggle get grouped for better mobile display -->
                    <div class="logo-box clearfix">
                        <a class="navbar-brand" href="<?php echo esc_url(home_url('/')); ?>">
                            <?php
                            $custom_logo_id = get_theme_mod( 'custom_logo' );
                            $logo = wp_get_attachment_image_src( $custom_logo_id , 'full' );
                            if ( has_custom_logo() ) {
                                    echo '<img src="' . esc_url( $logo[0] ) . '" alt="' . esc_attr(get_bloginfo( 'name' )) . '">';
                            } else {
                                    echo '<h1>'. esc_html(get_bloginfo( 'name' )) .'</h1>';
                            } ?>
                        </a>
                        <button class="menu-toggler side-menu__toggler">
                            <span class="fa fa-bars"></span>
                        </button>
                    </div><!-- /.logo-box -->
                    <!-- Collect the nav links, forms, and other content for toggling -->
                    <?php $zeino_page_nav_menu_condition = (empty(get_post_meta(get_the_ID(), 'zeino_menu_type', true))) ? 'primary_menu' : get_post_meta(get_the_ID(), 'zeino_menu_type', true); ?>
                    <?php if ( 'primary_menu' == $zeino_page_nav_menu_condition && is_page() ) : ?>
                        <div class="main-navigation">
                        	<?php
    						wp_nav_menu( array(
                                'theme_location' => 'menu-1',
                                'fallback_cb' => 'zeino_menu_fallback_cb',
    							'menu_class' => 'navigation-box one-page-scroll-menu',
    						) );
    						?>
                        </div><!-- /.navbar-collapse -->
                        <?php elseif ( 'one_page_menu' == $zeino_page_nav_menu_condition && is_page() ) :  ?>
                            <div class="main-navigation">
                                <?php
                                wp_nav_menu( array(
                                    'theme_location' => 'menu-2',
                                    'fallback_cb' => 'zeino_menu_fallback_cb',
                                    'menu_class' => 'navigation-box one-page-scroll-menu',
                                ) );
                                ?>
                            </div><!-- /.navbar-collapse -->
                        <?php elseif ( !is_page() ) :  ?>
                            <div class="main-navigation">
                                <?php
                                wp_nav_menu( array(
                                    'theme_location' => 'menu-1',
                                    'fallback_cb' => 'zeino_menu_fallback_cb',
                                    'menu_class' => 'navigation-box ',
                                ) );
                                ?>
                            </div><!-- /.navbar-collapse -->
                    <?php endif; ?>
                    <div class="header-one__right">
                        <?php if (true == get_theme_mod( 'header_btn_switch', false)) : ?>
                        <a href="<?php echo esc_url( get_theme_mod( 'header_btn_link', '#' ) ); ?>" class="thm-btn header-one__btn"><?php echo esc_html( get_theme_mod( 'header_btn_text', __( 'Btn Text', 'zeino' ) ) ); ?></a>
                        <?php endif; ?>
                    </div><!-- /.header-one__right -->
                </div>
                <!-- /.container -->
            </nav>
        </header><!-- /.header-one -->

        <?php $zeino_page_title_condition = empty( get_post_meta( get_the_ID(), 'zeino_show_page_header', true ) ) ? 'on' : get_post_meta( get_the_ID(), 'zeino_show_page_header', true );
              $zeino_page_title_text = get_post_meta( get_the_ID(), 'zeino_set_header_title', true );
        ?>
        <?php if ( 'off' == $zeino_page_title_condition && is_page() ) : ?>

            <?php elseif ( 'on' == $zeino_page_title_condition && is_page() ) :  ?>
            <section class="inner-banner" >
                <div class="container">
                    <h2 class="inner-banner__title">
                        <?php
                            if ( empty( $zeino_page_title_text ) ) {
                                esc_html(zeino_page_title());
                            }else {
                                echo esc_html( $zeino_page_title_text );
                            }
                        ?>

                    </h2><!-- /.inner-banner__title -->
                    <?php if (function_exists('zeino_wp_breadcrumb') && ('on' == get_theme_mod( 'breadcrumb_opt', 'on' ) )) {
                        zeino_wp_breadcrumb( 'ul', 'thm-breadcrumb', 'thm-breadcrumb', 'current', true );
                    } ?>
                </div><!-- /.container -->
            </section><!-- /.inner-banner -->

            <?php elseif ( !is_page() ) :  ?>
            <section class="inner-banner" >
                <div class="container">
                    <h2 class="inner-banner__title"><?php esc_html(zeino_page_title()); ?></h2><!-- /.inner-banner__title -->
                    <?php if (function_exists('zeino_wp_breadcrumb') && ('on' == get_theme_mod( 'breadcrumb_opt', 'on' ) )) {
                        zeino_wp_breadcrumb( 'ul', 'thm-breadcrumb', 'thm-breadcrumb', 'current', true );
                    } ?>
                </div><!-- /.container -->
            </section><!-- /.inner-banner -->

        <?php endif; ?>