<?php

$zeino_config_id = 'zeino_customize';

Kirki::add_config($zeino_config_id, array(
	'capability'    => 'edit_theme_options',
	'option_type'   => 'theme_mod',
));


/**
 * theme option panel master
 */

Kirki::add_panel('zeino_theme_opt', array(
	'priority'    => 240,
	'title'       => esc_html__('Zeino Options', 'zeino'),
	'description' => esc_html__('Zeino Theme options panel', 'zeino'),
));

/**
 * General options
 */
Kirki::add_section('zeino_theme_general', array(
	'title'          => esc_html__('General Settings', 'zeino'),
	'description'    => esc_html__('Zeino General Settings.', 'zeino'),
	'panel'          => 'zeino_theme_opt',
	'priority'       => 160,
));


// theme base color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_base_color',
	'label'       => __('Select Theme Base color', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => sanitize_hex_color('#e7062b'),
]);

// theme primary color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_primary_color',
	'label'       => __('Select Theme Primary color', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => sanitize_hex_color('#F7C324'),
]);

// theme black color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_black_color',
	'label'       => __('Select Theme Black color', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => sanitize_hex_color('#2a2d3b'),
]);

// theme gray color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'theme_gray_color',
	'label'       => __('Select Theme Gray color', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => sanitize_hex_color('#fbf8f4'),
]);




// general options fields

Kirki::add_field($zeino_config_id, [
	'type'        => 'switch',
	'settings'    => 'preloader',
	'label'       => esc_html__('Preloader Visibility', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'  => esc_html__('Enable', 'zeino'),
		'off' => esc_html__('Disable', 'zeino'),
	],
]);


Kirki::add_field($zeino_config_id, [
	'type'        => 'image',
	'settings'    => 'preloader_image',
	'label'       => esc_html__('Preloader Image', 'zeino'),
	'description' => esc_html__('Add your custom preloader image.', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => get_template_directory_uri() . '/assets/images/preloader.gif',
	'active_callback'  => [
		[
			'setting'  => 'preloader',
			'operator' => '===',
			'value'    => 'on',
		],
	]
]);


Kirki::add_field($zeino_config_id, [
	'type'        => 'switch',
	'settings'    => 'scroll_to_top',
	'label'       => esc_html__('Back to top Visibility', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'  => esc_html__('Enable', 'zeino'),
		'off' => esc_html__('Disable', 'zeino'),
	],
]);

Kirki::add_field($zeino_config_id, [
	'type'        => 'select',
	'settings'    => 'scroll_to_top_icon',
	'label'       => esc_html__('Select Back to top icon', 'zeino'),
	'section'     => 'zeino_theme_general',
	'default'     => 'fa-angle-up',
	'priority'    => 10,
	'multiple'    => 0,
	'choices'     => zeino_get_fa_icons(),
	'active_callback'  => [
		[
			'setting'  => 'scroll_to_top',
			'operator' => '===',
			'value'    => 'on',
		],
	]
]);

/**
 * Header options
 */
Kirki::add_section('zeino_theme_header', array(
	'title'          => esc_html__('Header Settings', 'zeino'),
	'description'    => esc_html__('Zeino Header Settings.', 'zeino'),
	'panel'          => 'zeino_theme_opt',
	'priority'       => 160,
));

// menu color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'header_default_menu_color',
	'label'       => __('Select Default Menu Item Link Color', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => sanitize_hex_color('#ffffff'),
]);

Kirki::add_field($zeino_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'header_btn_switch',
	'label'       => esc_html__('Header Btn Visibility', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => true,
	'priority'    => 10,
]);


Kirki::add_field($zeino_config_id, [
	'type'     => 'text',
	'settings' => 'header_btn_text',
	'label'    => esc_html__('Add Button', 'zeino'),
	'section'  => 'zeino_theme_header',
	'default'  => esc_html__('Btn Text', 'zeino'),
	'priority' => 10,
	'active_callback'  => function () {
		$switch_value = get_theme_mod('header_btn_switch', true);

		if (true === $switch_value) {
			return true;
		}
		return false;
	},
]);

Kirki::add_field($zeino_config_id, [
	'type'     => 'link',
	'settings' => 'header_btn_link',
	'label'    => __('Btn Link', 'zeino'),
	'section'  => 'zeino_theme_header',
	'default'  => 'https://wplemon.com/',
	'priority' => 10,
	'active_callback'  => function () {
		$switch_value = get_theme_mod('header_btn_switch', true);

		if (true === $switch_value) {
			return true;
		}
		return false;
	},
]);



// stricky switch
Kirki::add_field($zeino_config_id, [
	'type'        => 'checkbox',
	'settings'    => 'header_stricked_menu',
	'label'       => esc_html__('Stricky Header', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => true,
	'priority'    => 10,
]);


// stricky menu color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'header_stricked_menu_link_color',
	'label'       => __('Select Stricky Menu Item Link Color', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => sanitize_hex_color('#ffffff'),
	'active_callback'  => [
		[
			'setting'  => 'header_stricked_menu',
			'operator' => '==',
			'value'    => true,
		],
	]
]);

// sticky background type
Kirki::add_field($zeino_config_id, [
	'type'        => 'select',
	'settings'    => 'header_stricked_menu_bg_type',
	'label'       => esc_html__('Select Overlay Type', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => 'solid_color',
	'priority'    => 10,
	'multiple'    => 1,
	'choices'     => [
		'solid_color' => esc_html__('Solid Color', 'zeino'),
		'gradient' => esc_html__('Gradient Type', 'zeino'),
	],
	'active_callback'  => [
		[
			'setting'  => 'header_stricked_menu',
			'operator' => '==',
			'value'    => true,
		],
	]
]);


// solid color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'header_stricked_menu_bg_solid_color',
	'label'       => __('Select Overlay Color', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => sanitize_hex_color('#E7062B'),
	'active_callback'  => [
		[
			'setting'  => 'header_stricked_menu_bg_type',
			'operator' => '===',
			'value'    => 'solid_color',
		],
	]
]);

// gradient angles
Kirki::add_field($zeino_config_id, [
	'type'        => 'number',
	'settings'    => 'header_stricked_menu_bg_gradient_angle',
	'label'       => __('Select Gradient Angle', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => -120,
	'choices'     => [
		'min'  => -360,
		'max'  => 360,
		'step' => 1,
	],
	'active_callback'  => [
		[
			'setting'  => 'header_stricked_menu_bg_type',
			'operator' => '===',
			'value'    => 'gradient',
		],
	]
]);

// banner gradient colors
Kirki::add_field($zeino_config_id, [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Gradient Color', 'zeino'),
	'section'     => 'zeino_theme_header',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Gradient Colors', 'zeino'),
	],
	'button_label' => esc_html__('Add new Color', 'zeino'),
	'settings'     => 'header_stricked_menu_bg_gradient_color',
	'active_callback'  => [
		[
			'setting'  => 'header_stricked_menu_bg_type',
			'operator' => '===',
			'value'    => 'gradient',
		],
	],
	'default'      => [
		[
			'color' => sanitize_hex_color('#8d0f37'),
			'color_stop' => esc_html('0'),
		],
		[
			'color' => sanitize_hex_color('#c40a3b'),
			'color_stop' => esc_html('50'),
		],
		[
			'color' => sanitize_hex_color('#ea072e'),
			'color_stop' => esc_html('100'),
		],
	],
	'fields' => [
		'color'  => [
			'type'        => 'color',
			'label'       => esc_html__('Select Color', 'zeino'),
			'default'     => sanitize_hex_color('#E7062B'),
		],
		'color_stop' => [
			'type'        => 'number',
			'label'       => esc_html__('Color Stop', 'zeino'),
			'default'     => esc_html('50'),
			'choices'     => [
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			],
		],
	]
]);


// background image
Kirki::add_field($zeino_config_id, [
	'type'        => 'image',
	'settings'    => 'header_banner_image',
	'label'       => esc_html__('Header Banner Background Image', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => get_template_directory_uri() . '/assets/images/video-bg-1-1.jpg',
]);


// overlay type
Kirki::add_field($zeino_config_id, [
	'type'        => 'switch',
	'settings'    => 'header_banner_image_overlay',
	'label'       => esc_html__('Background Image Overlay Visibility', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => true,
	'priority'    => 10,
]);

// overlay opacity
Kirki::add_field($zeino_config_id, [
	'type'        => 'slider',
	'settings'    => 'header_banner_image_overlay_opacity',
	'label'       => esc_html__('Add Overlay Opacity', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => 90,
	'priority'    => 10,
	'choices'     => [
		'min'  => 0,
		'max'  => 100,
		'step' => 1,
	],
	'active_callback'  => [
		[
			'setting'  => 'header_banner_image_overlay',
			'operator' => '===',
			'value'    => true,
		],
	]
]);

// overlay type
Kirki::add_field($zeino_config_id, [
	'type'        => 'select',
	'settings'    => 'header_banner_image_overlay_type',
	'label'       => esc_html__('Select Overlay Type', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => 'solid_color',
	'priority'    => 10,
	'multiple'    => 1,
	'choices'     => [
		'solid_color' => esc_html__('Solid Color', 'zeino'),
		'gradient' => esc_html__('Gradient Type', 'zeino'),
	],
	'active_callback'  => [
		[
			'setting'  => 'header_banner_image_overlay',
			'operator' => '===',
			'value'    => true,
		],
	],
]);

// solid color
Kirki::add_field($zeino_config_id, [
	'type'        => 'color',
	'settings'    => 'header_banner_image_overlay_solid_color',
	'label'       => __('Select Overlay Color', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => sanitize_hex_color('#E7062B'),
	'active_callback'  => [
		[
			'setting'  => 'header_banner_image_overlay_type',
			'operator' => '===',
			'value'    => 'solid_color',
		],
	],
]);

// gradient angles

Kirki::add_field($zeino_config_id, [
	'type'        => 'number',
	'settings'    => 'header_banner_image_overlay_gradient_angle',
	'label'       => __('Select Gradient Angle', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => -120,
	'choices'     => [
		'min'  => -360,
		'max'  => 360,
		'step' => 1,
	],
	'active_callback'  => [
		[
			'setting'  => 'header_banner_image_overlay_type',
			'operator' => '===',
			'value'    => 'gradient',
		],
	],
]);

// banner gradient colors

Kirki::add_field($zeino_config_id, [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Gradient Color', 'zeino'),
	'section'     => 'zeino_theme_header',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Gradient Colors', 'zeino'),
	],
	'button_label' => esc_html__('Add new Color', 'zeino'),
	'settings'     => 'header_banner_image_overlay_gradient_color',
	'active_callback' => function () {
		if ('gradient' == get_theme_mod('header_banner_image_overlay_type')) {
			return true;
		} else {
			return false;
		}
	},
	'default'      => [
		[
			'color' => sanitize_hex_color('#8d0f37'),
			'color_stop' => esc_html('0'),
		],
		[
			'color' => sanitize_hex_color('#c40a3b'),
			'color_stop' => esc_html('50'),
		],
		[
			'color' => sanitize_hex_color('#ea072e'),
			'color_stop' => esc_html('100'),
		],
	],
	'fields' => [
		'color'  => [
			'type'        => 'color',
			'label'       => esc_html__('Select Color', 'zeino'),
			'default'     => sanitize_hex_color('#E7062B'),
		],
		'color_stop' => [
			'type'        => 'number',
			'label'       => esc_html__('Color Stop', 'zeino'),
			'default'     => esc_html('50'),
			'choices'     => [
				'min'  => 0,
				'max'  => 100,
				'step' => 1,
			],
		],
	]
]);


// header banner title


// header banner breadcrumb
Kirki::add_field($zeino_config_id, [
	'type'        => 'switch',
	'settings'    => 'breadcrumb_opt',
	'label'       => esc_html__('Breadcrumb Visibility', 'zeino'),
	'section'     => 'zeino_theme_header',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'  => esc_html__('Enable', 'zeino'),
		'off' => esc_html__('Disable', 'zeino'),
	],
]);


/**
 * Mobile Menu
 */

Kirki::add_section('zeino_theme_mobile_menu', array(
	'title'          => esc_html__('Mobile Menu Settings', 'zeino'),
	'description'    => esc_html__('Zeino Mobile Menu Settings.', 'zeino'),
	'panel'          => 'zeino_theme_opt',
	'priority'       => 160,
));

Kirki::add_field($zeino_config_id, [
	'type'     => 'textarea',
	'settings' => 'zeino_mobile_menu_text',
	'label'    => esc_html__('Mobile Menu Content', 'zeino'),
	'section'  => 'zeino_theme_mobile_menu',
	'default'  => esc_html__('Lorem Ipsum is simply dummy text the printing and setting industry. Lorm Ipsum has been the industry','zeino'),
	'priority' => 10,
]);

Kirki::add_field($zeino_config_id, [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Social Icons', 'zeino'),
	'section'     => 'zeino_theme_mobile_menu',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Social Icons', 'zeino'),
	],
	'button_label' => esc_html__('Add new Icon', 'zeino'),
	'settings'     => 'mobile_menu_social_icons',
	'default'      => [
		[
			'link_icon' => 'fa-facebook',
			'link_url' => esc_url('http://facebook.com'),
		],
	],
	'fields' => [
		'link_icon'  => [
			'type'        => 'select',
			'label'       => esc_html__('Social Icon', 'zeino'),
			'description' => esc_html__('Select Social Icons', 'zeino'),
			'default'     => 'fa-facebook',
			'choices'     => zeino_get_fa_icons(),
		],
		'link_url' => [
			'type'        => 'text',
			'label'       => esc_html__('Link Url', 'zeino'),
			'description' => esc_html__('Add social profile links', 'zeino'),
			'default'     => esc_url('https://facebook.com/'),
		],
	]
]);


/**
 * Footer options
 */

Kirki::add_section('zeino_theme_footer', array(
	'title'          => esc_html__('Footer Settings', 'zeino'),
	'description'    => esc_html__('Zeino Footer Settings.', 'zeino'),
	'panel'          => 'zeino_theme_opt',
	'priority'       => 160,
));

// Footer options fields
Kirki::add_field($zeino_config_id, [
	'type'        => 'switch',
	'settings'    => 'footer_bottom',
	'label'       => esc_html__('Footer bottom Visibility', 'zeino'),
	'section'     => 'zeino_theme_footer',
	'default'     => 'on',
	'priority'    => 10,
	'choices'     => [
		'on'  => esc_html__('Enable', 'zeino'),
		'off' => esc_html__('Disable', 'zeino'),
	],
]);

Kirki::add_field($zeino_config_id, [
	'type'     => 'text',
	'settings' => 'footer_copytext',
	'label'    => esc_html__('Text Control', 'zeino'),
	'section'  => 'zeino_theme_footer',
	'default'  => esc_html__('© copyright 2020 by ', 'zeino') . wp_kses('<a href="#">Layerdrops.com</a>', 'zeino_allowed_tags'),
	'priority' => 10,
	'active_callback' => function () {
		return get_theme_mod('footer_bottom');
	},
]);

Kirki::add_field($zeino_config_id, [
	'type'        => 'repeater',
	'label'       => esc_html__('Select Footer Social Icons', 'zeino'),
	'section'     => 'zeino_theme_footer',
	'priority'    => 10,
	'row_label' => [
		'type'  => 'text',
		'value' => esc_html__('Footer Social Icons', 'zeino'),
	],
	'button_label' => esc_html__('Add new Icon', 'zeino'),
	'settings'     => 'footer_social_icons',
	'active_callback' => function () {
		return get_theme_mod('footer_bottom');
	},
	'default'      => [
		[
			'link_icon' => esc_html('fa-facebook-f'),
			'link_url' => esc_url('http://facebook.com'),
		],
	],
	'fields' => [
		'link_icon'  => [
			'type'        => 'select',
			'label'       => esc_html__('Social Icon', 'zeino'),
			'description' => esc_html__('Select Social Icons', 'zeino'),
			'default'     => esc_html('fa-facebook-f'),
			'choices'     => zeino_get_fa_icons(),
		],
		'link_url' => [
			'type'        => 'text',
			'label'       => esc_html__('Link Url', 'zeino'),
			'description' => esc_html__('Add social profile links', 'zeino'),
			'default'     => esc_url('https://facebook.com/'),
		],
	]
]);
